==> netease_roomkit_interface-0.0.1-rc.0.tar.gz: lib/src/types/room_live_models.dart <==
class NERoomLiveRequest {
  final String title;
  final NELiveLayout liveLayout;
  final String? password;
  final bool liveChatRoomIndependent;
  final List<String?> liveUuids;
  final String? extras;

  NERoomLiveRequest(
      {required this.title,
      this.liveLayout = NELiveLayout.neRoomLiveLayoutGallery,
      this.password,
      this.liveChatRoomIndependent = false,
      required this.liveUuids,
      this.extras});
}

class NERoomLiveInfo {
  String? taskId;
  final String? pushUrl;
  final String? chatRoomId;
  final String? httpPullUrl;
  final String? rtmpPullUrl;
  final String? hlsPullUrl;
  final String? title;
  late NELiveLayout liveLayout;
  final String? password;
  late List<String?>? liveUuids;
  NELiveState state;
  final String? extras;

  NERoomLiveInfo(
      {required this.title,
      this.liveUuids,
      this.password,
      this.liveLayout = NELiveLayout.neRoomLiveLayoutGallery,
      this.chatRoomId,
      this.hlsPullUrl,
      this.httpPullUrl,
      this.pushUrl,
      this.rtmpPullUrl,
      this.extras,
      this.state = NELiveState.neRoomLiveStateInit,
      this.taskId});
}

enum NELiveLayout {
  ///无布局
  neRoomLiveLayoutNone,

  ///画廊布局
  neRoomLiveLayoutGallery,

  ///焦点布局
  neRoomLiveLayoutFocus,

  ///共享屏幕布局
  neRoomLiveLayoutScreenShare
}

extension NELiveLayoutEx on NELiveLayout {
  int liveLayout() {
    var liveLayout = 1;
    if (this == NELiveLayout.neRoomLiveLayoutFocus) {
      liveLayout = 2;
    } else if (this == NELiveLayout.neRoomLiveLayoutScreenShare) {
      liveLayout = 4;
    }
    return liveLayout;
  }

  static NELiveLayout fromLiveLayout(int? liveLayout) {
    switch (liveLayout) {
      case 2:
        return NELiveLayout.neRoomLiveLayoutFocus;
      case 4:
        return NELiveLayout.neRoomLiveLayoutScreenShare;
      default:
        return NELiveLayout.neRoomLiveLayoutGallery;
    }
  }
}

enum NELiveState {
  ///无效状态
  neRoomLiveStateInvalid,

  ///初始状态
  neRoomLiveStateInit,

  /// 直播中状态
  neRoomLiveStateStarted,

  ///直播结束状态
  neRoomLiveStateEnded,
}

///
/// 直播推流模式
///
enum NERoomLiveStreamMode {
  ///
  /// 推流音视频
  ///
  kVideo,

  ///
  /// 推流纯音频
  ///
  kAudio,
}

///
/// 直播推流视频和画布的适应属性
///
enum NERoomLiveStreamVideoScaleMode {
  ///
  /// 适应视频，视频尺寸等比缩放。优先保证视频内容全部显示。若视频尺寸与显示视窗尺寸不一致，视窗未被填满的区域填充背景色。
  ///
  kFit,

  ///
  /// （默认）适应区域，视频尺寸等比缩放。保证所有区域被填满，视频超出部分会被裁剪。
  ///
  kCropFill
}

///
/// 直播推流音频采样率
///
enum NERoomLiveStreamAudioSampleRate {
  ///
  /// 32K
  ///
  kAudioSampleRate32000,

  ///
  /// 44.1K
  ///
  kAudioSampleRate44100,

  ///
  /// 48K
  ///
  kAudioSampleRate48000,
}

///
/// 直播推流音频编码规格
///
enum NERoomLiveStreamAudioCodecProfile {
  ///
  /// NERtcLiveStreamAudioCodecProfileLCAAC: LC-AAC 规格，表示基本音频编码规格
  ///
  kLCAAC,

  ///
  /// NERtcLiveStreamAudioCodecProfileHEAAC: HE-AAC 规格，表示高效音频编码规格
  ///
  kHEAAC,
}

///
/// 直播推流任务的配置
///
class NERoomLiveStreamTaskInfo {
  /// 自定义的推流任务ID
  /// 字母、数字、下划线组成的 64 位以内的字符串。请保证此ID唯一。
  final String taskID;

  /// 推流地址
  /// 例如 **rtmp://test.url**。
  /// 此处的推流地址可设置为网易云信直播产品中服务端 API创建房间的返回参数pushUrl。
  final String streamURL;

  /// 旁路推流是否需要进行音视频录制
  /// 默认为关闭状态。
  final bool serverRecordEnabled;

  /// 预留参数
  /// 用户自定义的发送到旁路推流客户端的信息，用于填充 H264/H265 视频中 SEI 帧内容。长度限制：4096 字节。
  final String? extraInfo;

  /// 设置互动直播的画面布局
  final NERoomLiveStreamLayout layout;

  /// 音视频流编码参数等设置
  final NERoomLiveConfig? config;

  /// 直播推流模式
  /// 默认为 kVideo。详细信息请参考 [NERoomLiveStreamMode]。
  final NERoomLiveStreamMode lsMode;

  NERoomLiveStreamTaskInfo({
    required this.taskID,
    required this.streamURL,
    this.serverRecordEnabled = false,
    required this.layout,
    this.extraInfo,
    this.config,
    this.lsMode = NERoomLiveStreamMode.kVideo,
  });
}

///
/// 直播布局
///
class NERoomLiveStreamLayout {
  /// 整体画布的宽度
  /// 单位为 **px**。
  /// 取值范围为 **0~1920**，若设置为奇数值，会自动向下取偶。
  final int width;

  /// 整体画布的高度
  /// 单位为 **px**。取值范围为 **0~1920**，若设置为奇数值，会自动向下取偶。
  final int height;

  /// 画面背景颜色
  /// 格式为 256 ✖ 256 ✖ R + 256 ✖ G + B的和。请将对应 RGB 的值分别带入此公式计算即可。若未设置，则默认为0。
  final int backgroundColor;

  /// 成员布局数组
  /// 详细信息请参考 [NERoomLiveStreamUserTranscoding]。
  final List<NERoomLiveStreamUserTranscoding?> users;

  /// 占位图片
  /// 详细信息请参考 [NERoomStreamImageInfo]。
  final NERoomLiveStreamImageInfo? bgImage;

  NERoomLiveStreamLayout({
    required this.width,
    required this.height,
    this.backgroundColor = 0,
    required this.users,
    this.bgImage,
  });
}

///
/// 直播成员布局
///
class NERoomLiveStreamUserTranscoding {
  /// 成员ID
  final String userUuid;

  /// 是否在直播中向观看者播放该用户的对应视频流。
  ///
  /// 可设置为：
  ///
  /// - true：（默认）在直播中播放该用户的视频流。
  /// - false：在直播中不播放该用户的视频流。
  ///
  /// 推流模式为kNERtcLsModeAudio时无效。
  final bool videoPush;

  /// 用户图像的横轴坐标值
  ///
  /// 用于设置用户图像的横轴坐标值。
  /// 通过 x 和 y 指定画布坐标中的一个点，该点将作为用户图像的左上角。
  /// 取值范围为 **0~1920**，若设置为奇数值，会自动向下取偶。
  ///
  /// 用户图像范围如果超出超出画布，调用方法时会报错。
  final int x;

  /// 用户图像的纵轴坐标值
  ///
  /// 用于设置用户图像的纵轴坐标值。
  /// 通过 x 和 y 指定画布坐标中的一个点，该点将作为用户图像的左上角。
  /// 取值范围为 **0~1920**，若设置为奇数值，会自动向下取偶。
  ///
  /// 用户图像范围如果超出超出画布，调用方法时会报错。
  final int y;

  /// 用户图像在画布中的宽度
  ///
  /// 取值范围为 **0~1920**，默认为**0**。
  /// 若设置为奇数值，会自动向下取偶。
  ///
  /// 用户图像范围如果超出超出画布，调用方法时会报错。
  final int width;

  /// 用户图像在画布中的高度
  ///
  /// 取值范围为 **0~1920**，默认为**0**。
  /// 若设置为奇数值，会自动向下取偶。
  ///
  /// 用户图像范围如果超出超出画布，调用方法时会报错。
  final int height;

  /// 是否在直播中混流该用户的对应音频流
  ///
  /// 可设置为：
  ///
  /// - true：（默认）在直播中混流该用户的对应音频流。
  /// - false：在直播中将该用户设置为静音。
  final bool audioPush;

  /// 图层编号
  ///
  /// 用来决定渲染层级, 取值 **0-100**, 0位于最底层，100位于最顶层，相同层级的渲染区域按照现有的覆盖逻辑实现（按照数组中顺序进行渲染，index递增依次往上叠加）
  final int zOrder;

  /// 直播推流视频和画布的适应属性。详细信息请参考 [NERoomLiveStreamVideoScaleMode]。
  final NERoomLiveStreamVideoScaleMode adaption;

  NERoomLiveStreamUserTranscoding({
    required this.userUuid,
    required this.x,
    required this.y,
    required this.width,
    required this.height,
    this.videoPush = true,
    this.audioPush = true,
    this.zOrder = 0,
    this.adaption = NERoomLiveStreamVideoScaleMode.kFit,
  });
}

/// 图片布局
class NERoomLiveStreamImageInfo {
  /// 占位图片的URL
  final String url;

  /// 横轴坐标值
  ///
  /// 用于设置画布的横轴坐标值。
  /// 通过 x 和 y 指定画布坐标中的一个点，该点将作为占位图片的左上角。
  /// 取值范围为 **0~1920**，若设置为奇数值，会自动向下取偶。
  final int x;

  /// 纵轴坐标值
  ///
  /// 用于设置画布的纵轴坐标值。
  /// 通过 x 和 y 指定画布坐标中的一个点，该点将作为占位图片的左上角。
  /// 取值范围为 **0~1920**，若设置为奇数值，会自动向下取偶。
  final int y;

  /// 画布中的宽度。
  ///
  /// 取值范围为 **0~1920**，若设置为奇数值，会自动向下取偶。
  final int width;

  /// 画布中的高度。
  ///
  /// 取值范围为 **0~1920**，若设置为奇数值，会自动向下取偶。
  final int height;

  NERoomLiveStreamImageInfo({
    required this.url,
    required this.x,
    required this.y,
    required this.width,
    required this.height,
  });
}

/// 音视频流编码参数等设置
class NERoomLiveConfig {
  /// 单路视频透传开关
  ///
  /// 默认为关闭状态。
  /// 开启后，如果房间中只有一路视频流输入， 则不对输入视频流进行转码，不遵循转码布局，直接推流 CDN。
  /// 如果有多个房间成员视频流混合为一路流，则该设置失效，并在恢复为一个成员画面（单路流）时也不会恢复。
  final bool singleVideoPassthrough;

  /// 音频推流码率
  ///
  /// 单位为 **kbps**，取值范围为 **10~192**。
  /// 语音场景建议设置为 64 及以上码率，音乐场景建议设置为 128 及以上码率。
  final int audioBitrate;

  /// 音频推流采样率
  ///
  /// 单位为**Hz**，可设置为：
  ///
  /// - 32000：采样率为 32 kHz。
  /// - 44100：采样率为 44.1 kHz。
  /// - （默认）48000：采样率为 48 kHz。
  final NERoomLiveStreamAudioSampleRate sampleRate;

  /// 音频推流声道数
  ///
  /// - 1：单声道。
  /// - 2：（默认）双声道。
  final int channels;

  /// 音频编码规格
  /// 详细信息请参考 [NERoomLiveStreamAudioCodecProfile]。
  final NERoomLiveStreamAudioCodecProfile audioCodecProfile;

  NERoomLiveConfig({
    this.singleVideoPassthrough = false,
    this.audioBitrate = 64,
    this.sampleRate = NERoomLiveStreamAudioSampleRate.kAudioSampleRate48000,
    this.channels = 2,
    this.audioCodecProfile = NERoomLiveStreamAudioCodecProfile.kLCAAC,
  });
}

==> netease_roomkit_interface-1.26.0.tar.gz: lib/src/types/room_live_models.dart <==
// Copyright (c) 2022 NetEase, Inc. All rights reserved.
// Use of this source code is governed by a MIT license that can be
// found in the LICENSE file.

class NERoomLiveRequest {
  final String title;
  final NERoomLiveLayout liveLayout;
  final String? password;
  final List<String?> userUuidList;
  final String? extensionConfig;

  NERoomLiveRequest(
      {required this.title,
      required this.liveLayout,
      this.password,
      required this.userUuidList,
      this.extensionConfig});
}

class NERoomLiveInfo {
  String? taskId;
  final String? pushUrl;
  final String? chatRoomId;
  final String? httpPullUrl;
  final String? rtmpPullUrl;
  final String? hlsPullUrl;
  final String? title;
  late NERoomLiveLayout liveLayout;
  final String? password;
  late List<String?>? userUuidList;
  NERoomLiveState state;
  final String? extensionConfig;

  NERoomLiveInfo(
      {required this.title,
      this.userUuidList,
      this.password,
      this.liveLayout = NERoomLiveLayout.none,
      this.chatRoomId,
      this.hlsPullUrl,
      this.httpPullUrl,
      this.pushUrl,
      this.rtmpPullUrl,
      this.extensionConfig,
      this.state = NERoomLiveState.invalid,
      this.taskId});
}

enum NERoomLiveLayout {
  ///无布局
  none,

  ///画廊布局
  gallery,

  ///焦点布局
  focus,

  ///共享屏幕布局
  screenShare
}

extension NERoomLiveLayoutEx on NERoomLiveLayout {
  int liveLayout() {
    var liveLayout = 1;
    if (this == NERoomLiveLayout.focus) {
      liveLayout = 2;
    } else if (this == NERoomLiveLayout.screenShare) {
      liveLayout = 4;
    }
    return liveLayout;
  }

  static NERoomLiveLayout fromLiveLayout(int? liveLayout) {
    switch (liveLayout) {
      case 2:
        return NERoomLiveLayout.focus;
      case 4:
        return NERoomLiveLayout.screenShare;
      default:
        return NERoomLiveLayout.gallery;
    }
  }
}

enum NERoomLiveState {
  ///无效状态
  invalid,

  ///初始状态
  init,

  /// 直播中状态
  started,

  ///直播结束状态
  ended,
}

///
/// 直播推流模式
///
enum NERoomLiveStreamMode {
  ///
  /// 推流音视频
  ///
  kVideo,

  ///
  /// 推流纯音频
  ///
  kAudio,
}

///
/// 直播推流视频和画布的适应属性
///
enum NERoomLiveStreamVideoScaleMode {
  ///
  /// 适应视频，视频尺寸等比缩放。优先保证视频内容全部显示。若视频尺寸与显示视窗尺寸不一致，视窗未被填满的区域填充背景色。
  ///
  kFit,

  ///
  /// （默认）适应区域，视频尺寸等比缩放。保证所有区域被填满，视频超出部分会被裁剪。
  ///
  kCropFill
}

///
/// 直播推流音频采样率
///
enum NERoomLiveStreamAudioSampleRate {
  ///
  /// 32K
  ///
  kAudioSampleRate32000,

  ///
  /// 44.1K
  ///
  kAudioSampleRate44100,

  ///
  /// 48K
  ///
  kAudioSampleRate48000,
}

///
/// 直播推流音频编码规格
///
enum NERoomLiveStreamAudioCodecProfile {
  ///
  /// NERtcLiveStreamAudioCodecProfileLCAAC: LC-AAC 规格，表示基本音频编码规格
  ///
  kLCAAC,

  ///
  /// NERtcLiveStreamAudioCodecProfileHEAAC: HE-AAC 规格，表示高效音频编码规格
  ///
  kHEAAC,
}

///
/// 直播推流任务的配置
///
class NERoomLiveStreamTaskInfo {
  /// 自定义的推流任务ID
  /// 字母、数字、下划线组成的 64 位以内的字符串。请保证此ID唯一。
  final String taskId;

  /// 推流地址
  /// 例如 **rtmp://test.url**。
  /// 此处的推流地址可设置为网易云信直播产品中服务端 API创建房间的返回参数pushUrl。
  final String streamUrl;

  /// 旁路推流是否需要进行音视频录制
  /// 默认为关闭状态。
  final bool serverRecordEnabled;

  /// 预留参数
  /// 用户自定义的发送到旁路推流客户端的信息，用于填充 H264/H265 视频中 SEI 帧内容。长度限制：4096 字节。
  final String? extraInfo;

  /// 设置互动直播的画面布局
  final NERoomLiveStreamLayout layout;

  /// 音视频流编码参数等设置
  final NERoomLiveConfig? config;

  /// 直播推流模式
  /// 默认为 kVideo。详细信息请参考 [NERoomLiveStreamMode]。
  final NERoomLiveStreamMode mode;

  NERoomLiveStreamTaskInfo({
    required this.taskId,
    required this.streamUrl,
    this.serverRecordEnabled = false,
    required this.layout,
    this.extraInfo,
    this.config,
    this.mode = NERoomLiveStreamMode.kVideo,
  });
}

///
/// 直播布局
///
class NERoomLiveStreamLayout {
  /// 整体画布的宽度
  /// 单位为 **px**。
  /// 取值范围为 **0~1920**，若设置为奇数值，会自动向下取偶。
  final int width;

  /// 整体画布的高度
  /// 单位为 **px**。取值范围为 **0~1920**，若设置为奇数值，会自动向下取偶。
  final int height;

  /// 画面背景颜色
  /// 格式为 256 ✖ 256 ✖ R + 256 ✖ G + B的和。请将对应 RGB 的值分别带入此公式计算即可。若未设置，则默认为0。
  final int backgroundColor;

  /// 成员布局数组
  /// 详细信息请参考 [NERoomLiveStreamUserTranscoding]。
  final List<NERoomLiveStreamUserTranscoding?> userTranscodingList;

  /// 占位图片
  /// 详细信息请参考 [NERoomStreamImageInfo]。
  final NERoomLiveStreamImageInfo? backgroundImg;

  NERoomLiveStreamLayout({
    required this.width,
    required this.height,
    this.backgroundColor = 0,
    required this.userTranscodingList,
    this.backgroundImg,
  });
}

///
/// 直播成员布局
///
class NERoomLiveStreamUserTranscoding {
  /// 成员ID
  final String userUuid;

  /// 是否在直播中向观看者播放该用户的对应视频流。
  ///
  /// 可设置为：
  ///
  /// - true：（默认）在直播中播放该用户的视频流。
  /// - false：在直播中不播放该用户的视频流。
  ///
  /// 推流模式为kNERtcLsModeAudio时无效。
  final bool videoPush;

  /// 用户图像的横轴坐标值
  ///
  /// 用于设置用户图像的横轴坐标值。
  /// 通过 x 和 y 指定画布坐标中的一个点，该点将作为用户图像的左上角。
  /// 取值范围为 **0~1920**，若设置为奇数值，会自动向下取偶。
  ///
  /// 用户图像范围如果超出超出画布，调用方法时会报错。
  final int x;

  /// 用户图像的纵轴坐标值
  ///
  /// 用于设置用户图像的纵轴坐标值。
  /// 通过 x 和 y 指定画布坐标中的一个点，该点将作为用户图像的左上角。
  /// 取值范围为 **0~1920**，若设置为奇数值，会自动向下取偶。
  ///
  /// 用户图像范围如果超出超出画布，调用方法时会报错。
  final int y;

  /// 用户图像在画布中的宽度
  ///
  /// 取值范围为 **0~1920**，默认为**0**。
  /// 若设置为奇数值，会自动向下取偶。
  ///
  /// 用户图像范围如果超出超出画布，调用方法时会报错。
  final int width;

  /// 用户图像在画布中的高度
  ///
  /// 取值范围为 **0~1920**，默认为**0**。
  /// 若设置为奇数值，会自动向下取偶。
  ///
  /// 用户图像范围如果超出超出画布，调用方法时会报错。
  final int height;

  /// 是否在直播中混流该用户的对应音频流
  ///
  /// 可设置为：
  ///
  /// - true：（默认）在直播中混流该用户的对应音频流。
  /// - false：在直播中将该用户设置为静音。
  final bool audioPush;

  /// 图层编号
  ///
  /// 用来决定渲染层级, 取值 **0-100**, 0位于最底层，100位于最顶层，相同层级的渲染区域按照现有的覆盖逻辑实现（按照数组中顺序进行渲染，index递增依次往上叠加）
  final int zOrder;

  /// 直播推流视频和画布的适应属性。详细信息请参考 [NERoomLiveStreamVideoScaleMode]。
  final NERoomLiveStreamVideoScaleMode adaption;

  NERoomLiveStreamUserTranscoding({
    required this.userUuid,
    required this.x,
    required this.y,
    required this.width,
    required this.height,
    this.videoPush = true,
    this.audioPush = true,
    this.zOrder = 0,
    this.adaption = NERoomLiveStreamVideoScaleMode.kFit,
  });
}

/// 图片布局
class NERoomLiveStreamImageInfo {
  /// 占位图片的URL
  final String url;

  /// 横轴坐标值
  ///
  /// 用于设置画布的横轴坐标值。
  /// 通过 x 和 y 指定画布坐标中的一个点，该点将作为占位图片的左上角。
  /// 取值范围为 **0~1920**，若设置为奇数值，会自动向下取偶。
  final int x;

  /// 纵轴坐标值
  ///
  /// 用于设置画布的纵轴坐标值。
  /// 通过 x 和 y 指定画布坐标中的一个点，该点将作为占位图片的左上角。
  /// 取值范围为 **0~1920**，若设置为奇数值，会自动向下取偶。
  final int y;

  /// 画布中的宽度。
  ///
  /// 取值范围为 **0~1920**，若设置为奇数值，会自动向下取偶。
  final int width;

  /// 画布中的高度。
  ///
  /// 取值范围为 **0~1920**，若设置为奇数值，会自动向下取偶。
  final int height;

  NERoomLiveStreamImageInfo({
    required this.url,
    required this.x,
    required this.y,
    required this.width,
    required this.height,
  });
}

/// 音视频流编码参数等设置
class NERoomLiveConfig {
  /// 单路视频透传开关
  ///
  /// 默认为关闭状态。
  /// 开启后，如果房间中只有一路视频流输入， 则不对输入视频流进行转码，不遵循转码布局，直接推流 CDN。
  /// 如果有多个房间成员视频流混合为一路流，则该设置失效，并在恢复为一个成员画面（单路流）时也不会恢复。
  final bool singleVideoPassthrough;

  /// 音频推流码率
  ///
  /// 单位为 **kbps**，取值范围为 **10~192**。
  /// 语音场景建议设置为 64 及以上码率，音乐场景建议设置为 128 及以上码率。
  final int audioBitrate;

  /// 音频推流采样率
  ///
  /// 单位为**Hz**，可设置为：
  ///
  /// - 32000：采样率为 32 kHz。
  /// - 44100：采样率为 44.1 kHz。
  /// - （默认）48000：采样率为 48 kHz。
  final NERoomLiveStreamAudioSampleRate sampleRate;

  /// 音频推流声道数
  ///
  /// - 1：单声道。
  /// - 2：（默认）双声道。
  final int channels;

  /// 音频编码规格
  /// 详细信息请参考 [NERoomLiveStreamAudioCodecProfile]。
  final NERoomLiveStreamAudioCodecProfile audioCodecProfile;

  NERoomLiveConfig({
    this.singleVideoPassthrough = false,
    this.audioBitrate = 64,
    this.sampleRate = NERoomLiveStreamAudioSampleRate.kAudioSampleRate48000,
    this.channels = 2,
    this.audioCodecProfile = NERoomLiveStreamAudioCodecProfile.kLCAAC,
  });
}
